Unadjusted local minimal p-value
local_min_p.RdGiven \(k\) child p-values, returns the highest p-value below alpha; if none are below alpha returns the smallest p-value.
local_min_p.RdGiven \(k\) child p-values, returns the highest p-value below alpha; if none are below alpha returns the smallest p-value.